@@ -49,7 +49,8 @@ public:
   DataSetReaderImpl(const std::string& dataModel,
                     DataModelInput inputType,
                     bool streamSteps,
-                    const Params& params)
+                    const Params& params,
+                    bool createSharedPoints)
   {
     this->StreamingMode = streamSteps;
     this->Cleanup();
@@ -67,6 +68,10 @@ public:
       this->ParsingChecks(doc, dataModel, inputType);
       this->ReadJSON(doc);
     }
+    for (auto it : this->DataSources)
+    {
+      it.second->CreateSharedPoints = createSharedPoints;
+    }
 
     this->SetDataSourceParameters(params);
   }
@@ -710,20 +715,23 @@ bool DataSetReader::CheckForDataModelAttribute(const std::string& filename,
 
 DataSetReader::DataSetReader(const std::string& dataModel,
                              DataModelInput inputType /*=DataModelInput::JSONFile*/,
-                             const Params& params)
-  : DataSetReader(dataModel, inputType, false, params)
+                             const Params& params,
+                             bool createSharedPoints /*=false*/)
+  : DataSetReader(dataModel, inputType, false, params, createSharedPoints)
 {
 }
 
 DataSetReader::DataSetReader(const std::string& dataModel,
                              DataModelInput inputType,
                              bool streamSteps,
-                             const Params& params)
+                             const Params& params,
+                             bool createSharedPoints /*=false*/)
   : Impl(nullptr)
 {
   if (inputType != DataModelInput::BPFile)
   {
-    this->Impl.reset(new DataSetReaderImpl(dataModel, inputType, streamSteps, params));
+    this->Impl.reset(
+      new DataSetReaderImpl(dataModel, inputType, streamSteps, params, createSharedPoints));
     return;
   }
 
@@ -744,7 +752,8 @@ DataSetReader::DataSetReader(const std::string& dataModel,
     {
       if (predefined::DataModelSupported(result[0]))
       {
-        this->Impl.reset(new DataSetReaderImpl(dataModel, inputType, streamSteps, params));
+        this->Impl.reset(
+          new DataSetReaderImpl(dataModel, inputType, streamSteps, params, createSharedPoints));
         return;
       }
     }
@@ -757,8 +766,8 @@ DataSetReader::DataSetReader(const std::string& dataModel,
     auto schema = source->ReadAttribute<std::string>(schemaAttr);
     if (!schema.empty())
     {
-      this->Impl.reset(
-        new DataSetReaderImpl(schema[0], DataModelInput::JSONString, streamSteps, params));
+      this->Impl.reset(new DataSetReaderImpl(
+        schema[0], DataModelInput::JSONString, streamSteps, params, createSharedPoints));
       return;
     }
   }
